@@ -314,8 +314,8 @@ JLL = Instruction(
         ]
     )
 
-JGL: = Instruction(
-        'JGL:',
+JGL = Instruction(
+        'JGL',
         0x22,
         [
             Argument('target', PTR),
@@ -387,7 +387,7 @@ instructions = {
         0x1F: MVL,
         0x20: JEL,
         0x21: JLL,
-        0x22: JGL:,
+        0x22: JGL,
         0x23: PKB,
         0x24: PKI,
         0x25: PKL,
